@@ -65,14 +65,13 @@ add_difference <- function(x, test = NULL, group = NULL,
                            pvalue_fun = NULL, estimate_fun = NULL) {
   # checking inputs ------------------------------------------------------------
   updated_call_list <- c(x$call_list, list(add_difference = match.call()))
-  if (!inherits(x, c("tbl_summary", "tbl_svysummary"))) {
-    stop("`x=` must be class 'tbl_summary' or 'tbl_svysummary'", call. = FALSE)
-  }
+  .assert_class(x, c("tbl_summary", "tbl_svysummary"))
+
   if (is.null(x$by) || nrow(x$df_by) != 2) {
     stop("'tbl_summary'/'tbl_svysummary' object must have a `by=` value with exactly two levels", call. = FALSE)
   }
-  if ("add_p" %in% names(x$call_list)) {
-    stop("`add_difference()` cannot be run after `add_p()`", call. = FALSE)
+  if (any(c("add_p", "add_difference") %in% names(x$call_list))) {
+    stop("`add_difference()` cannot be run after `add_p()` or `add_difference()`", call. = FALSE)
   }
   if (rlang::is_function(estimate_fun)) {
     lifecycle::deprecate_warn(
@@ -88,7 +87,7 @@ add_difference <- function(x, test = NULL, group = NULL,
   include <-
     .select_to_varnames(
       select = {{ include }},
-      data = select(use_data_frame(x$inputs$data), any_of(x$meta_data$variable)),
+      data = select(.extract_data_frame(x$inputs$data), any_of(x$meta_data$variable)),
       var_info = x$table_body,
       arg_name = "include"
     )
@@ -96,7 +95,7 @@ add_difference <- function(x, test = NULL, group = NULL,
   test <-
     .formula_list_to_named_list(
       x = test,
-      data = select(use_data_frame(x$inputs$data), any_of(include)),
+      data = select(.extract_data_frame(x$inputs$data), any_of(include)),
       var_info = x$table_body,
       arg_name = "test",
       type_check = chuck(type_check, "is_function_or_string", "fn"),
@@ -106,7 +105,7 @@ add_difference <- function(x, test = NULL, group = NULL,
   estimate_fun <-
     .formula_list_to_named_list(
       x = {{ estimate_fun }},
-      data = select(use_data_frame(x$inputs$data), any_of(x$meta_data$variable)),
+      data = select(.extract_data_frame(x$inputs$data), any_of(x$meta_data$variable)),
       var_info = x$table_body,
       arg_name = "estimate_fun",
       type_check = chuck(type_check, "is_function", "fn"),
@@ -128,7 +127,7 @@ add_difference <- function(x, test = NULL, group = NULL,
   adj.vars <-
     .select_to_varnames(
       select = {{ adj.vars }},
-      data = use_data_frame(x$inputs$data),
+      data = .extract_data_frame(x$inputs$data),
       var_info = x$table_body,
       arg_name = "adj.vars"
     )
@@ -137,13 +136,13 @@ add_difference <- function(x, test = NULL, group = NULL,
     pvalue_fun %||%
     get_theme_element("add_p.tbl_summary-arg:pvalue_fun") %||%
     get_theme_element("pkgwide-fn:pvalue_fun") %||%
-    getOption("gtsummary.pvalue_fun", default = style_pvalue) %>%
+    .get_deprecated_option("gtsummary.pvalue_fun", default = style_pvalue) %>%
     gts_mapper("add_p(pvalue_fun=)")
 
   group <-
     .select_to_varnames(
       select = {{ group }},
-      data = use_data_frame(x$inputs$data),
+      data = .extract_data_frame(x$inputs$data),
       var_info = x$table_body,
       arg_name = "group",
       select_single = TRUE
@@ -208,7 +207,7 @@ add_difference <- function(x, test = NULL, group = NULL,
   test.args <-
     .formula_list_to_named_list(
       x = test.args,
-      data = select(use_data_frame(x$inputs$data), any_of(include)),
+      data = select(.extract_data_frame(x$inputs$data), any_of(include)),
       var_info = x$table_body,
       arg_name = "test.args",
       type_check = chuck(type_check, "is_named", "fn"),
@@ -258,7 +257,3 @@ add_difference <- function(x, test = NULL, group = NULL,
   x
 }
 
-use_data_frame <- function(x) {
-  if (is.data.frame(x)) return(x)
-  x$variables # return survey object data frame
-}
