@@ -252,7 +252,7 @@ tbl_survfit.data.frame <- function(x, y, include = everything(), ...) {
   include <- dplyr::select(x, {{ include }}) %>% names()
 
   # checking inputs ------------------------------------------------------------
-  check_haven_labelled(x)
+  check_haven_labelled(x, include)
 
   # able to construct Surv() object?
   y <- enexpr(y)
@@ -276,7 +276,7 @@ tbl_survfit.data.frame <- function(x, y, include = everything(), ...) {
   if (!inherits(y_surv, "Surv")) {
     paste(
       "Together, the data frame in `x=`, and the survival outcome in `y=`",
-      "must construct `Surv` oject, e.g. `with(trial, Surv(ttdeath, death))`"
+      "must construct `Surv` object, e.g. `with(trial, Surv(ttdeath, death))`"
     ) %>%
       stringr::str_wrap() %>%
       stop(call. = FALSE)
