@@ -64,11 +64,12 @@ tbl_survival.survfit <- function(x, times = NULL, probs = NULL,
                                  missing = "-",
                                  estimate_fun = NULL,
                                  ...) {
+  check_dots_empty(error = function(e) inform(c(e$message, e$body)))
 
   # setting defaults -----------------------------------------------------------
   estimate_fun <-
     estimate_fun %||%
-    getOption("gtsummary.tbl_survival.estimate_fun") %||%
+    .get_deprecated_option("gtsummary.tbl_survival.estimate_fun") %||%
     switch(is.null(times) + 1,
       partial(style_percent, symbol = TRUE),
       partial(style_sigfig, digits = 3)
