@@ -96,7 +96,6 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
   if (!is.data.frame(data) && !is_survey(data)) {
     stop("`data` argument must be a data frame or survey object.", call. = FALSE)
   }
-  check_haven_labelled(data)
 
   # setting defaults -----------------------------------------------------------
   pvalue_fun <-
@@ -179,6 +178,7 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
       data = .extract_data_frame(data),
       arg_name = "show_single_row"
     )
+  check_haven_labelled(data, include)
 
   # checking formula correctly specified ---------------------------------------
   if (!rlang::is_string(formula)) {
