@@ -110,6 +110,7 @@ add_p_test_lme4 <- function(data, variable, by, group, type, ...) {
 add_p_tbl_summary_paired.t.test <- function(data, variable, by, group,
                                             test.args = NULL, conf.level = 0.95, ...) {
   quiet <- FALSE # need to add support for quiet later
+  if (missing(group) || is.null(group)) stop("Paired tests require the `group=` argument.", call. = FALSE)
   .superfluous_args(variable, ...)
   # checking inputs
   if (length(data[[by]] %>% stats::na.omit() %>% unique()) != 2) {
@@ -213,6 +214,7 @@ add_p_tbl_summary_paired.wilcox.test <- function(data, variable, by, group,
                                                  test.args = NULL, conf.level = 0.95,
                                                  quiet = FALSE, ...) {
   .superfluous_args(variable, ...)
+  if (missing(group) || is.null(group)) stop("Paired tests require the `group=` argument.", call. = FALSE)
   # checking inputs
   if (length(data[[by]] %>% stats::na.omit() %>% unique()) != 2) {
     stop("`by=` must have exactly 2 levels", call. = FALSE)
@@ -609,13 +611,13 @@ add_p_tbl_survfit_survdiff <- function(data, variable, test.args, ...) {
   broom::glance(survdiff_result) %>%
     dplyr::mutate(
       method =
-        switch(is.null(test.args$rho) || test.args$rho == 0,
-               "Log-rank test"
-        ) %||%
-        switch(test.args$rho == 1,
-               "Peto & Peto modification of Gehan-Wilcoxon test"
-        ) %||%
-        stringr::str_glue("G-rho (\U03C1 = {test.args$rho}) test")
+        purrr::when(
+          test.args$rho,
+          is.null(.) || . == 0 ~ "Log-rank test",
+          . == 1 ~ "Peto & Peto modification of Gehan-Wilcoxon test",
+          . == 1.5 ~ "Tarone-Ware test",
+          TRUE ~ stringr::str_glue("G-rho (\U03C1 = {test.args$rho}) test")
+        )
     )
 }
 
@@ -629,6 +631,11 @@ add_p_tbl_survfit_petopeto_gehanwilcoxon <- function(data, variable, ...) {
   add_p_tbl_survfit_survdiff(data, test.args = list(rho = 1))
 }
 
+add_p_tbl_survfit_tarone <- function(data, variable, ...) {
+  .superfluous_args(variable, ...)
+  add_p_tbl_survfit_survdiff(data, test.args = list(rho = 1.5))
+}
+
 add_p_tbl_survfit_coxph <- function(data, variable, test_type, test.args, ...) {
   .superfluous_args(variable, ...)
   # formula and data calls
