@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(requireNamespace("car"))
+skip_if_not(broom.helpers::.assert_package("car", pkg_search = "gtsummary", boolean = TRUE))
 
 test_that("no errors/warnings with standard", {
   expect_error(
