@@ -17,7 +17,7 @@ test_that("tbl_svysummary creates output without error/warning (no by var)", {
 })
 
 
-test_that("tbl_svtsummary creates output without error/warning (with by var)", {
+test_that("tbl_svysummary creates output without error/warning (with by var)", {
   statistics <- list(
     all_continuous() ~ "{median} {mean} {sd} {var} {min} {max} {sum} {p25} {p42} {p75} {p89}",
     all_categorical() ~ "{n} {N} {p} | {n_unweighted} {N_unweighted} {p_unweighted}"
@@ -207,9 +207,9 @@ test_that("tbl_svysummary-testing tidyselect parsing", {
   expect_equal(
     big_test$table_body %>%
       filter(.data$variable %in% c("age", "marker")) %>%
-      pull(.data$stat_1) %>%
-      word(2) %>%
-      word(2, sep = fixed(".")) %>%
+      dplyr::pull(.data$stat_1) %>%
+      stringr::word(2) %>%
+      stringr::word(2, sep = fixed(".")) %>%
       nchar() %>%
       unique(),
     3
@@ -409,11 +409,12 @@ test_that("tbl_svysummary-no error when by variable is ordered factor", {
 })
 
 test_that("tbl_svysummary-provides similar results than tbl_summary for simple weights", {
-  t1 <- survey::svydesign(~1, data = as.data.frame(Titanic), weights = ~Freq) %>%
-    tbl_svysummary(include = c(Class, Sex, Age, Survived))
-  t2 <- as.data.frame(Titanic) %>%
-    tidyr::uncount(Freq) %>%
-    tbl_summary()
+  d1 <- survey::svydesign(~1, data = as.data.frame(Titanic), weights = ~Freq)
+  d2 <- as.data.frame(Titanic) %>% tidyr::uncount(Freq)
+
+  # col percentages
+  t1 <- d1 %>% tbl_svysummary(include = c(Class, Sex, Age, Survived))
+  t2 <- d2 %>% tbl_summary(include = c(Class, Sex, Age, Survived))
   expect_equal(t1$table_body, t2$table_body)
   expect_equal(
     t1$table_styling %>% purrr::list_modify(header = NULL),
@@ -424,6 +425,40 @@ test_that("tbl_svysummary-provides similar results than tbl_summary for simple w
     t2$table_styling$header %>% select(-contains("unweighted"))
   )
 
+  # row percentages
+  t1 <- d1 %>%
+    tbl_svysummary(include = c(Class, Sex), by = Survived, percent = "row") %>%
+    add_overall()
+  t2 <- d2 %>%
+    tbl_summary(include = c(Class, Sex), by = Survived, percent = "row") %>%
+    add_overall()
+  expect_equal(t1$table_body, t2$table_body)
+  expect_equal(
+    t1$table_styling %>% purrr::list_modify(header = NULL),
+    t2$table_styling %>% purrr::list_modify(header = NULL)
+  )
+  expect_equal(
+    tmp <- t1$table_styling$header %>% select(-contains("unweighted")),
+    t2$table_styling$header %>% select(all_of(names(tmp))) # order of variables can differ
+  )
+
+  # cell percentages
+  t1 <- d1 %>%
+    tbl_svysummary(include = c(Class, Sex), by = Survived, percent = "cell") %>%
+    add_overall()
+  t2 <- d2 %>%
+    tbl_summary(include = c(Class, Sex), by = Survived, percent = "cell") %>%
+    add_overall()
+  expect_equal(t1$table_body, t2$table_body)
+  expect_equal(
+    t1$table_styling %>% purrr::list_modify(header = NULL),
+    t2$table_styling %>% purrr::list_modify(header = NULL)
+  )
+  expect_equal(
+    tmp <- t1$table_styling$header %>% select(-contains("unweighted")),
+    t2$table_styling$header %>% select(all_of(names(tmp))) # order of variables can differ
+  )
+
   statistic <- list(all_continuous() ~ "{mean}", all_categorical() ~ "{n} ({p}%)")
   t1 <- survey::svydesign(~1, data = trial, weights = ~1) %>%
     tbl_svysummary(by = trt, statistic = statistic)
@@ -571,3 +606,27 @@ test_that("tbl_svysummary() works with date and date/time", {
     c(NA, "44%", "56%")
   )
 })
+
+test_that("tbl_svysummary() works with 0/1 variables", {
+  expect_error(
+    survey::svydesign(data = trial, ids = ~ 1, weights = ~ 1) %>%
+      tbl_svysummary(include = response),
+    NA
+  )
+})
+
+test_that("tbl_svysummary() works with a factor having only one levem", {
+  d <- tibble(fct = factor(c("a", "a", "a", "a", "a"))) %>%
+    survey::svydesign(data = ., ids = ~ 1, weights = ~ 1)
+
+  expect_error(
+    res <- d %>% tbl_svysummary(),
+    NA
+  )
+
+  expect_equal(
+    res$table_body$stat_0,
+    c(NA, "5 (100%)")
+  )
+})
+
